Welcome to svhnL's documentation!
===================================

**svhnL** is a Python library for downloading and processing images for a multi-digit recognition (MDR) task
under any major deep learning framework [TensorFlow, JAX, Torch]. In summary, the library provides function to 
download, extract datasets from `the original SVHN dataset <http://ufldl.stanford.edu/housenumbers/>`_, convert annotation file format,
and generate datasets that are specially designed for MDR tasks.

Check out the :doc:`usage` section for further information, including
how to :ref:`installation` the project.

.. note::

   This project is under active development.

Contents
--------

.. toctree::

   usage
   api
